/*
 * deviced
 *
 * Copyright (c) 2014 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#include <glib.h>
#include <string.h>

#include "core/config-parser.h"

#include "test.h"
#include "config.h"

#define CONF_FILE		"/etc/deviced/auto-test.conf"
#define DEF_PROFILE		"mobile"

static char section[256] = {'\0',};
static GHashTable *config_hash = NULL;

static int load_config(struct parse_result *result, void *user_data)
{
	int value = 0;

	if (!MATCH(result->section, section))
		return 0;

	_D("%s,%s,%s", result->section, result->name, result->value);

	value = atoi(result->value);
	if ((value == 1) && !g_hash_table_contains(config_hash, result->name))
		g_hash_table_add(config_hash, g_strdup(result->name));

	return 0;
}

void test_config_load(const char *profile)
{
	int len = 0;
	int ret = 0;

	if (NULL != profile)	len = strlen(profile);
	if ((0 >= len) || (255 < len))
		strncpy(section, DEF_PROFILE, 255);
	else
		strncpy(section, profile, 255);


	if (NULL != config_hash)
		test_config_unload();

	config_hash = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, NULL);
	if (NULL == config_hash) {
		_E("Failed to create config hash table!");
		return ;
	}

	ret = config_parse(CONF_FILE, load_config, NULL);

	if (ret < 0) {
		_E("Failed to load %s, %d Use default value!", CONF_FILE, ret);
		test_config_unload();
	}
}

void test_config_unload()
{
	if (NULL != config_hash) {
		g_hash_table_unref(config_hash);
		config_hash = NULL;
	}
}

bool test_config_is_supported(const char *module)
{
	// if fail to load config file, all modules are supported as default.
	//if ((NULL == module) || (NULL == config_hash) || (0 == g_hash_table_size(config_hash)))
	if ((NULL == module) || (NULL == config_hash))
		return TRUE;

	return g_hash_table_contains(config_hash, module);
}
